typedcols - README
================================================================================

.. warning::

    Although production code is based on this library, it should still be considered
    as work in progress.


Introduction
--------------------------------------------------------------------------------

Python 2 and 3 compatible library providing typed collections.

This README file is work in progress, sorry about that.


Copyright
--------------------------------------------------------------------------------

| Copyright (c) since 2016, CESNET, z. s. p. o.
| Author: Pavel Kácha <pavel.kacha@cesnet.cz>
| Use of this package is governed by the ISC license, see LICENSE file.
|
